self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "afa38b260af05950d5b0ef86caa313ee",
    "url": "./index.html"
  },
  {
    "revision": "cbd1faa90120276b06b4",
    "url": "./static/css/main.239f2e9a.chunk.css"
  },
  {
    "revision": "88348afa62d5d2837327",
    "url": "./static/js/2.740fea40.chunk.js"
  },
  {
    "revision": "bf56b6cdf7ded6c60e4459c9d99a2449",
    "url": "./static/js/2.740fea40.chunk.js.LICENSE.txt"
  },
  {
    "revision": "cbd1faa90120276b06b4",
    "url": "./static/js/main.cbf68461.chunk.js"
  },
  {
    "revision": "7e9d84e346ce158d1e50",
    "url": "./static/js/runtime-main.44d30fc2.js"
  }
]);