(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{100:function(e,t,a){e.exports=a(114)},106:function(e,t,a){},114:function(e,t,a){"use strict";a.r(t);var n=a(0),r=a.n(n),o=a(22),l=a.n(o),s=a(1),i=a(2),c=a(4),p=a(5),d=a(80),u=a(131),f=a(130),m=(a(106),a(94)),g=a(93),y=a(95),E=function(e){Object(c.a)(a,e);var t=Object(p.a)(a);function a(){var e;Object(i.a)(this,a);for(var n=arguments.length,o=new Array(n),l=0;l<n;l++)o[l]=arguments[l];return(e=t.call.apply(t,[this].concat(o))).state={score:.7,isUploading:!1,progress:1,files:[],onDrop:function(t){e.setState({files:t}),e.setState({isUploading:!0}),setInterval((function(){e.state.progress<=100&&e.setState((function(e){return{progress:Math.floor(e.progress+100/30)}}))}),100),setTimeout((function(){t.forEach((function(t){var a=new FileReader;a.onabort=function(){alert("file reading was aborted"),e.setState({isUploading:!1,progress:1})},a.onerror=function(){alert("file reading has failed"),e.setState({isUploading:!1,progress:1})},a.onload=function(){var t=a.result;console.log(t),d.a.setComponentValue(t),e.setState({isUploading:!1,progress:1})},a.readAsText(t)}))}),2e3)}},e.render=function(){return r.a.createElement("div",{style:{background:"#11111",width:"100%",display:"flex",justifyContent:"center"}},r.a.createElement("div",{style:{background:"#262730",width:"70%"}},e.state.isUploading&&r.a.createElement(m.a,{centered:!0,open:e.state.isUploading,footer:null,closable:!1},r.a.createElement(g.a,{style:{display:"flex",justifyContent:"center",padding:"20px"},type:"circle",percent:e.state.progress,strokeColor:"#FF4B4B",trailColor:"#888C9C",format:function(e){return r.a.createElement("span",{style:{color:"#fff"}},e,"%")}}),r.a.createElement("p",{style:{textAlign:"center",fontSize:16}},"We are processing the data you have uploaded")),r.a.createElement(y.a,{onDrop:e.state.onDrop},(function(e){var t=e.getRootProps,a=e.getInputProps;return r.a.createElement("section",{className:"container",style:{border:"1px solid transparent",background:"#32333D",cursor:"pointer",textAlign:"center",padding:"60px 0px",borderRadius:5}},r.a.createElement("div",t({className:"dropzone"}),r.a.createElement("input",a()),r.a.createElement("div",null,r.a.createElement("p",{className:"ant-upload-drag-icon"},r.a.createElement(u.a,{id:"CloudUploadOutlined"})),r.a.createElement("p",{className:"ant-upload-text",style:{color:"#fff",margin:"unset"}},"Drag and drop files here"),r.a.createElement("p",{className:"ant-upload-hint",style:{color:"grey",fontSize:13}},"Limit 200MB per file"),r.a.createElement(f.a,{variant:"contained",color:"primary",style:{background:"#FF4B4B",width:180,margin:10}},"Browse file"),r.a.createElement("p",{className:"ant-upload-hint",style:{color:"grey",fontSize:13}},"(CSV file only)"))))}))))},e}return Object(s.a)(a)}(d.b),b=Object(d.c)(E);l.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(b,null)),document.getElementById("root"))}},[[100,1,2]]]);
//# sourceMappingURL=main.cbf68461.chunk.js.map