.main-div{background:#262730;height:391px}#dragger{background:#32333d;border:none!important}#CloudUploadOutlined,.similarity{color:#fff}#CloudUploadOutlined{font-size:56px}.grey-text{color:#888c9c}.ant-slider-handle:after{background-color:#ff4b4b!important;border-color:#ff4b4b!important;box-shadow:0 0 0 2px #ff4b4b!important}#aaaa{border-radius:5px;background-color:#32333d}.ant-modal-content{background-color:#32333d!important;color:#fff!important;padding:60px 0!important}.cardComponentDiv,.dashboardParentDiv{background:#111;color:#fff}.groupNameHeading{font-size:20px;font-weight:400;padding-top:5px}.NameGroup{display:flex;justify-content:space-between}.CSVButton{margin-left:10px;border:1px solid #ff4b4b!important;color:#ff4b4b!important;width:180px;height:35px;background-color:#32333d}.uploadButton{border:1px solid #32333d!important;background-color:#32333d}.settingButton,.uploadButton{padding-bottom:10px;width:44px;height:35px}.settingButton{margin-left:10px;border:1px solid #ff4b4b!important;background-color:#ff4b4b}.CSVButton :active,.CSVButton :hover,.settingButton{color:#ff4b4b!important}.summarySection{border-radius:5px;background-color:#32333d!important;color:#fff!important;font-size:13px;margin-top:20px;padding:5px 0}.summary{margin:10px 25px;color:#fff;font-size:13px}.summaryParagraph{color:#888c9c;margin:10px 25px}.topicCard{background-color:#32333d!important;border-radius:5px}.similerText,.topics{text-align:justify;margin:20px 20px 0 25px;line-height:2rem;letter-spacing:2px;color:#fff}.similerTextParagraph,.topicParagraph{color:#888c9c;margin:15px 25px;font-size:16px}.previousButton{border:1px solid #32333d!important;border-radius:5px;margin:0 10px;width:150px;height:50px;background-color:#32333d!important;color:#888c9c!important}.previousButton :focus{border:1px solid #32333d!important}.dropdownButton{border:1px solid #32333d!important;border-radius:5px;font-size:16px;background-color:#32333d!important}.dropdownButton,.NextButton{width:150px;height:50px;margin:0 10px;color:#fff!important}.NextButton{border:1px solid #ff4b4b!important;border-radius:5px;background-color:#ff4b4b!important}button:focus{outline:1px rgba(2,2,2,0);outline:none!important}.ant-space{grid-gap:65px!important;gap:65px!important}.customDropdown .ant-dropdown-menu{background-color:#32333d!important}.setScroll{overflow:auto;height:200px;scrollbar-width:thin}.setScroll::-webkit-scrollbar{width:.2rem;height:20px!important}.setScroll::-webkit-scrollbar-track{background-color:#32333d}.setScroll::-webkit-scrollbar-thumb{background-color:#fff;border-radius:9px;height:20px!important}
/*# sourceMappingURL=main.239f2e9a.chunk.css.map */